#property copyright ""
#property link      ""
#property strict

#property indicator_chart_window
#property indicator_buffers 6
#property indicator_color1  PaleVioletRed
#property indicator_color2  LimeGreen
#property indicator_color3  PaleVioletRed
#property indicator_color4  LimeGreen
#property indicator_color5  PaleVioletRed
#property indicator_color6  LimeGreen
#property indicator_style1  STYLE_DOT
#property indicator_style2  STYLE_DOT
#property indicator_width3  2
#property indicator_width4  2
#property indicator_width5  3
#property indicator_width6  3

extern int    FastLength      = 3;
extern int    SlowLength      = 7;
extern double SlowPipDisplace = 0;
extern double FastPipDisplace = 0;

bool   AlertsOn        = false;
bool   AlertsOnCurrent = false;
bool   AlertsMessage   = false;
bool   AlertsSound     = false;
bool   AlertsEmail     = false;
bool   ShowColoredBars = false;
bool   ShowLines       = false;
bool   ShowArrows      = true;

double line1[];
double line2[];
double hist1[];
double hist2[];
double arrou[];
double arrod[];
double trend[];
double trena[];

int init()
{
   int type1 = DRAW_NONE; if (ShowLines)       type1 = DRAW_LINE;
   int type2 = DRAW_NONE; if (ShowColoredBars) type2 = DRAW_HISTOGRAM;
   int type3 = DRAW_NONE; if (ShowArrows)      type3 = DRAW_ARROW;
   
   IndicatorBuffers(8);
      SetIndexBuffer(0,line1); SetIndexStyle(0,type1);
      SetIndexBuffer(1,line2); SetIndexStyle(1,type1);
      SetIndexBuffer(2,hist1); SetIndexStyle(2,type2);
      SetIndexBuffer(3,hist2); SetIndexStyle(3,type2);
      SetIndexBuffer(4,arrod); SetIndexStyle(4,type3); SetIndexArrow(4,159);
      SetIndexBuffer(5,arrou); SetIndexStyle(5,type3); SetIndexArrow(5,159);
      SetIndexBuffer(6,trend);
      SetIndexBuffer(7,trena);
   IndicatorShortName(WindowExpertName());
   return(0);
}


int start()
{
   int i,limit;
   int counted_bars = IndicatorCounted();
   //---- check for possible errors
   if(counted_bars < 0) {
       return(-1);
   }
   if(counted_bars <= SlowLength*10) {
       limit = Bars - SlowLength*10 ;
   }else{
       limit = Bars - counted_bars;   
   } 
         
   double pipMultiplier = 1; if (Digits==3 || Digits==5) pipMultiplier =10;
      
      for (i = limit; i >= 0; i--)
      {   
         double thigh1 = High[iHighest(NULL, 0, MODE_HIGH, SlowLength,i)] + SlowPipDisplace*Point*pipMultiplier;
         double tlow1  = Low[iLowest(NULL, 0, MODE_LOW, SlowLength,i)]    - SlowPipDisplace*Point*pipMultiplier;
         double thigh2 = High[iHighest(NULL, 0, MODE_HIGH, FastLength,i)] + FastPipDisplace*Point*pipMultiplier;
         double tlow2  = Low[iLowest(NULL, 0, MODE_LOW, FastLength,i)]    - FastPipDisplace*Point*pipMultiplier;
            if (Close[i]>line1[i+1])
                  line1[i] = tlow1;
            else  line1[i] = thigh1;             
            if (Close[i]>line2[i+1])
                  line2[i] = tlow2;
            else  line2[i] = thigh2;             
            
            hist1[i] = EMPTY_VALUE;
            hist2[i] = EMPTY_VALUE;
            arrou[i] = EMPTY_VALUE;
            arrod[i] = EMPTY_VALUE;
            trena[i] = trena[i+1];
            trend[i] = 0;
               if (Close[i]<line1[i] && Close[i]<line2[i]) trend[i] =  1;
               if (Close[i]>line1[i] && Close[i]>line2[i]) trend[i] = -1;
               if (line1[i]>line2[i] || trend[i] ==  1)    trena[i] =  1;
               if (line1[i]<line2[i] || trend[i] == -1)    trena[i] = -1;
               if (trend[i]== 1) { hist1[i] = High[i]; hist2[i] = Low[i]; }
               if (trend[i]==-1) { hist2[i] = High[i]; hist1[i] = Low[i]; }
               if (trena[i]!=trena[i+1])
                  if (trena[i] == 1) 
                        arrod[i] = MathMax(line1[i],line2[i]);
                  else  arrou[i] = MathMin(line1[i],line2[i]);                        
      }
      manageAlerts();
      return(0);   
}

void manageAlerts()
{
   if (AlertsOn)
   {
      int whichBar;
      if (AlertsOnCurrent)
            whichBar = 0;
      else  whichBar = 1;
      if (arrod[whichBar] != EMPTY_VALUE || arrou[whichBar] != EMPTY_VALUE)
      {
         static datetime time1 = 0;
         static string   mess1 = "";
            if (arrou[whichBar] != EMPTY_VALUE) doAlert(time1,mess1," ptl trend changed to up");
            if (arrod[whichBar] != EMPTY_VALUE) doAlert(time1,mess1," ptl trend changed to down");
      }
   }
}

void doAlert(datetime& previousTime, string& previousAlert, string doWhat)
{
   string message;
   
   if (previousAlert != doWhat || previousTime != Time[0]) {
       previousAlert  = doWhat;
       previousTime   = Time[0];

       message =   StringConcatenate( Period()," ",Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS))+doWhat;
          if (AlertsMessage) Alert(message);
          if (AlertsEmail)   SendMail(Symbol()+" ptl",message);
          if (AlertsSound)   PlaySound("alert2.wav");
   }
}